@@ -9,6 +9,7 @@ from simc_support.game_data.Language import Translation
 from simc_support.game_data.SimcObject import SimcObject
 from simc_support.game_data.WowSpec import WowSpec
 from simc_support.game_data.WowSpec import WOWSPECS
+from simc_support.game_data.WowSpec import get_wow_spec
 
 
 class Conduit(SimcObject):
@@ -116,10 +117,20 @@ def get_conduits_for_spec(wow_spec: WowSpec) -> typing.Tuple[Conduit, ...]:
       tuple[Conduit] -- Tuple of all dps Conduits
     """
 
+    # spell_id lists
+    SPECIAL_CASES = {
+        get_wow_spec("death_knight", "blood"): [
+            338566,  # Lingering Plague, 125
+        ]
+    }
+
     conduits = [
         conduit
         for conduit in CONDUITS
-        if wow_spec in conduit.wow_specs and conduit.is_potency
+        if wow_spec in conduit.wow_specs
+        and conduit.is_potency
+        or wow_spec in SPECIAL_CASES
+        and conduit.spell_id in SPECIAL_CASES[wow_spec]
     ]
 
     return tuple(conduits)
