@@ -2,12 +2,14 @@ import enum
 
 
 class Source(enum.Enum):
+    CALLING = "Calling"
     DUNGEON = "Dungeon"
+    MISSION = "Mission"
     PROFESSION = "Profession"
     PVP = "PvP"
     RAID = "Raid"
-    UNKNOWN = "Unknown"
     RARE_MOB = "Rare Mob"
+    UNKNOWN = "Unknown"
     WORLD_BOSS = "World Boss"
     WORLD_DROP = "World Drop"
     WORLD_QUEST = "World Quest"
